@@ -19,18 +19,19 @@ class MapCSSRule;
 class MapCSSParserPrivate
 {
 public:
-    void parse(MapCSSStyle *style, const QString &fileName);
+    void parse(MapCSSStyle *style, const QString &fileName, ClassSelectorKey importClass);
 
     /** @internal for use by the generated parser only. */
-    bool addImport(char *fileName);
+    [[nodiscard]] bool addImport(char *fileName, ClassSelectorKey importClass);
     void addRule(MapCSSRule *rule);
     void setError(const QString &msg, int line, int column);
 
-    ClassSelectorKey makeClassSelector(const char *str, std::size_t len);
-    LayerSelectorKey makeLayerSelector(const char *str, std::size_t len);
+    [[nodiscard]] ClassSelectorKey makeClassSelector(const char *str, std::size_t len) const;
+    [[nodiscard]] LayerSelectorKey makeLayerSelector(const char *str, std::size_t len) const;
 
     MapCSSStyle *m_currentStyle = nullptr;
     QString m_currentFileName;
+    ClassSelectorKey m_importClass;
     bool m_error = false;
     QString m_errorMsg;
     int m_line = 0;
